stalker.core.models.Booking
===========================

.. inheritance-diagram::
     stalker.core.models.Booking
     :parts: 1

.. currentmodule:: stalker.core.models

.. autoclass:: Booking
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Booking.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Booking.code
      ~Booking.created_by
      ~Booking.date_created
      ~Booking.date_updated
      ~Booking.description
      ~Booking.name
      ~Booking.nice_name
      ~Booking.notes
      ~Booking.tags
      ~Booking.type
      ~Booking.updated_by
   
   